# CreateSessionAndTokenResponse

The response object for creating a session and associated token
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**token** | [**RawToken**](RawToken.md) |  | [optional] 
**session** | [**Session**](Session.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


